==> llm-docs-0.1.4.tgz: package/docs/components/bfcicomponents/nodejs-base.md <==
---
id: components-bfcicomponents-nodejs-base
---
# Node.js Base Component

The `nodejs-base` component provides a standardized foundation for Node.js projects in GitLab CI/CD pipelines.

## Purpose

This component:

- Configures Node.js environment with specified version
- Sets up caching for faster builds
- Defines reusable job templates for dependency installation
- Handles environment preparation for CI
- Dynamically defines pipeline stages
- Supports custom Docker image configuration

## Inputs

| Input                    | Description                                          | Default                                                                                            | Options                                            |
| ------------------------ | ---------------------------------------------------- | -------------------------------------------------------------------------------------------------- | -------------------------------------------------- |
| `node_version`           | Node.js version to use for the jobs                  | `"20"`                                                                                             | `"16"`, `"18"`, `"20"`, `"21"`                     |
| `project_type`           | Type of Node.js project for optimized configurations | `"app"`                                                                                            | `"app"`, `"library"`, `"api"`, `"cli"`             |
| `cache_strategy`         | Strategy for caching dependencies                    | `"default"`                                                                                        | `"default"`, `"aggressive"`, `"minimal"`, `"none"` |
| `stages`                 | List of stages to include in the pipeline            | `"build, test, docs, deploy, publish"`                                                             | Any comma-separated list of stages                 |
| `enable_default_install` | Add a default job for installing dependencies        | `true`                                                                                             | `true`, `false`                                    |
| `use_custom_image`       | Use LLM Platform custom Docker image                      | `true`                                                                                             | `true`, `false`                                    |
| `custom_image_path`      | Path to custom Docker image                          | `"registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest"` | Any valid image path                               |
| `package_manager`        | Package manager to use                               | `"auto"`                                                                                           | `"auto"`, `"npm"`, `"yarn"`, `"pnpm"`              |

## Provided Jobs

| Job       | Description                   | Conditions                                 |
| --------- | ----------------------------- | ------------------------------------------ |
| `install` | Installs Node.js dependencies | Runs when `enable_default_install` is true |

## Reusable Job Templates

The component provides these reusable job templates that can be extended in your pipeline:

| Template                  | Description                             |
| ------------------------- | --------------------------------------- |
| `.node_base`              | Base configuration for all Node.js jobs |
| `.detect_package_manager` | Script to determine package manager     |
| `.install_dependencies`   | Template for installing dependencies    |
| `.setup_workspace`        | Template for setting up the workspace   |

## Cache Configuration

The component configures caching based on the `cache_strategy` input:

- `default`: Caches the `node_modules` directory
- `aggressive`: Caches the npm cache directory (`~/.npm`)
- `minimal`: Uses pull-only cache policy
- `none`: Disables caching

## Custom Docker Image Support

When `use_custom_image` is set to `true`, the component will use the specified custom Docker image instead of the standard Node.js image. This ensures consistent environments across CI/CD pipelines:

```yaml
include:
  - component: 'gitlab://blueflyio/BFCIComponents/components/nodejs-base.yml'
    inputs:
      use_custom_image: true
      custom_image_path: 'registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest'
```

## Package Manager Auto-Detection

When `package_manager` is set to `"auto"`, the component will automatically detect the correct package manager based on lockfiles:

- `yarn.lock` → Yarn
- `pnpm-lock.yaml` → pnpm
- Otherwise → npm

## Local Dependency Handling

The component automatically executes a `prepare-ci.sh` script if it exists in the repository root. This script can be used to replace local file dependencies with appropriate alternatives for CI environments.

## Usage Example

```yaml
include:
  - component: 'gitlab://blueflyio/BFCIComponents/components/nodejs-base.yml'
    inputs:
      node_version: '20'
      project_type: 'api'
      cache_strategy: 'aggressive'
      use_custom_image: true

# Extend the node_base template in your jobs
my_custom_job:
  extends: .node_base
  stage: build
  script:
    - echo "Running a custom job"
    - npm run custom-script
```

## Advanced Configuration

### Custom Stages

To define custom pipeline stages:

```yaml
inputs:
  stages: 'prepare, lint, build, test, deploy'
```

### Disabling Default Jobs

If you want to handle dependency installation yourself:

```yaml
inputs:
  enable_default_install: false
```

### Using Standard Node.js Image

If you need to use the standard Node.js image rather than the custom one:

```yaml
inputs:
  use_custom_image: false
```

## Troubleshooting

### Missing Node Modules

If jobs are failing with missing dependencies despite the `install` job:

1. Check that your job depends on the `install` job using `needs: [install]`
2. Verify the `install` job is running successfully
3. Try using `cache_strategy: "aggressive"` for improved caching

### Local Dependencies Issues

If you're encountering errors related to local dependencies:

1. Create a `prepare-ci.sh` script in your project root
2. Implement logic to replace local dependencies with published versions
3. Make the script executable with `chmod +x prepare-ci.sh`

Example `prepare-ci.sh`:

```bash
#!/bin/bash
sed -i 's|"bfcommon": "file:../BFCommon"|"bfcommon": "1.0.0"|g' package.json
```

==> llm-docs-1.0.1.tgz: package/docs/components/bfcicomponents/nodejs-base.md <==
---
id: components-bfcicomponents-nodejs-base
---
# Node.js Base Component

The `nodejs-base` component provides a standardized foundation for Node.js projects in GitLab CI/CD pipelines.

## Purpose

This component:

- Configures Node.js environment with specified version
- Sets up caching for faster builds
- Defines reusable job templates for dependency installation
- Handles environment preparation for CI
- Dynamically defines pipeline stages
- Supports custom Docker image configuration

## Inputs

| Input                    | Description                                          | Default                                                                                            | Options                                            |
| ------------------------ | ---------------------------------------------------- | -------------------------------------------------------------------------------------------------- | -------------------------------------------------- |
| `node_version`           | Node.js version to use for the jobs                  | `"20"`                                                                                             | `"16"`, `"18"`, `"20"`, `"21"`                     |
| `project_type`           | Type of Node.js project for optimized configurations | `"app"`                                                                                            | `"app"`, `"library"`, `"api"`, `"cli"`             |
| `cache_strategy`         | Strategy for caching dependencies                    | `"default"`                                                                                        | `"default"`, `"aggressive"`, `"minimal"`, `"none"` |
| `stages`                 | List of stages to include in the pipeline            | `"build, test, docs, deploy, publish"`                                                             | Any comma-separated list of stages                 |
| `enable_default_install` | Add a default job for installing dependencies        | `true`                                                                                             | `true`, `false`                                    |
| `use_custom_image`       | Use Bluefly custom Docker image                      | `true`                                                                                             | `true`, `false`                                    |
| `custom_image_path`      | Path to custom Docker image                          | `"registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest"` | Any valid image path                               |
| `package_manager`        | Package manager to use                               | `"auto"`                                                                                           | `"auto"`, `"npm"`, `"yarn"`, `"pnpm"`              |

## Provided Jobs

| Job       | Description                   | Conditions                                 |
| --------- | ----------------------------- | ------------------------------------------ |
| `install` | Installs Node.js dependencies | Runs when `enable_default_install` is true |

## Reusable Job Templates

The component provides these reusable job templates that can be extended in your pipeline:

| Template                  | Description                             |
| ------------------------- | --------------------------------------- |
| `.node_base`              | Base configuration for all Node.js jobs |
| `.detect_package_manager` | Script to determine package manager     |
| `.install_dependencies`   | Template for installing dependencies    |
| `.setup_workspace`        | Template for setting up the workspace   |

## Cache Configuration

The component configures caching based on the `cache_strategy` input:

- `default`: Caches the `node_modules` directory
- `aggressive`: Caches the npm cache directory (`~/.npm`)
- `minimal`: Uses pull-only cache policy
- `none`: Disables caching

## Custom Docker Image Support

When `use_custom_image` is set to `true`, the component will use the specified custom Docker image instead of the standard Node.js image. This ensures consistent environments across CI/CD pipelines:

```yaml
include:
  - component: 'gitlab://blueflyio/BFCIComponents/components/nodejs-base.yml'
    inputs:
      use_custom_image: true
      custom_image_path: 'registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest'
```

## Package Manager Auto-Detection

When `package_manager` is set to `"auto"`, the component will automatically detect the correct package manager based on lockfiles:

- `yarn.lock` → Yarn
- `pnpm-lock.yaml` → pnpm
- Otherwise → npm

## Local Dependency Handling

The component automatically executes a `prepare-ci.sh` script if it exists in the repository root. This script can be used to replace local file dependencies with appropriate alternatives for CI environments.

## Usage Example

```yaml
include:
  - component: 'gitlab://blueflyio/BFCIComponents/components/nodejs-base.yml'
    inputs:
      node_version: '20'
      project_type: 'api'
      cache_strategy: 'aggressive'
      use_custom_image: true

# Extend the node_base template in your jobs
my_custom_job:
  extends: .node_base
  stage: build
  script:
    - echo "Running a custom job"
    - npm run custom-script
```

## Advanced Configuration

### Custom Stages

To define custom pipeline stages:

```yaml
inputs:
  stages: 'prepare, lint, build, test, deploy'
```

### Disabling Default Jobs

If you want to handle dependency installation yourself:

```yaml
inputs:
  enable_default_install: false
```

### Using Standard Node.js Image

If you need to use the standard Node.js image rather than the custom one:

```yaml
inputs:
  use_custom_image: false
```

## Troubleshooting

### Missing Node Modules

If jobs are failing with missing dependencies despite the `install` job:

1. Check that your job depends on the `install` job using `needs: [install]`
2. Verify the `install` job is running successfully
3. Try using `cache_strategy: "aggressive"` for improved caching

### Local Dependencies Issues

If you're encountering errors related to local dependencies:

1. Create a `prepare-ci.sh` script in your project root
2. Implement logic to replace local dependencies with published versions
3. Make the script executable with `chmod +x prepare-ci.sh`

Example `prepare-ci.sh`:

```bash
#!/bin/bash
sed -i 's|"bfcommon": "file:../BFCommon"|"bfcommon": "1.0.0"|g' package.json
```
